==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/nb_NO.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitet",
    "Personal activity feed for %s" : "Personlig aktivitetsstrøm for %s",
    "Your feed URL is invalid" : "Kilde URL er ikke gyldig",
    "Your settings have been updated." : "Innstillingene dine ble oppdatert.",
    "Mail" : "E-post",
    "Stream" : "Strøm",
    "Activities" : "Aktiviteter",
    "Error loading activities" : "Feil ved innlasting av aktiviteter",
    "No activities" : "Ingen aktiviteter",
    "This stream will show events like additions, changes & shares" : "Denne strømmen vil vise hendelser som f.eks. innlegging, endring og deling",
    "There are no events for this filter" : "Der er ingen hendelser for dette filteret",
    "Activity notification" : "Varsel om aktivitet",
    "All Activities" : "All aktivitet",
    "Activities by you" : "Din aktivitet",
    "Activities by others" : "Andres aktivitet",
    "\"remote user\"" : "\"ekstern bruker\"",
    "in %s" : "i %s",
    "%s and %s" : "%s og %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s og <strong %s>%n flere</strong>","%s og <strong %s>%n flere</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s og %n til","%s og %n til"],
    "Hello %s," : "Hei %s,",
    "You are receiving this email because the following things happened at %s" : "Du mottar denne e-posten fordi følgende har hendt på %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* og %n til ","* og %n til "],
    "Notifications" : "Varsler",
    "List your own actions in the stream" : "List dine egne handlinger i strømmen",
    "Notify about your own actions via email" : "Varsle om dine egne handliger via e-post",
    "You need to set up your email address before you can receive notification emails." : "Du må sette opp e-postadressen din før du kan motta varslinger på e-post.",
    "Send emails:" : "Send e-poster:",
    "Hourly" : "Hver time",
    "Daily" : "Daglig",
    "Weekly" : "Ukentlig",
    "Activity feed" : "Aktivitetsstrøm",
    "Enable RSS feed" : "Aktiver RSS-strøm",
    "No activity yet" : "Ingen aktivitet ennå",
    "No more events to load" : "Ingen flere hendelser å laste",
    "Files" : "Filer",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s og <strong class=\"has-tooltip\" title=\"%s\">%n flere</strong>","%s og <strong class=\"has-tooltip\" title=\"%s\">%n flere</strong>"]
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/nb_NO.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitet",
    "Personal activity feed for %s" : "Personlig aktivitetsstrøm for %s",
    "Your feed URL is invalid" : "Kilde URL er ikke gyldig",
    "Your settings have been updated." : "Innstillingene dine ble oppdatert.",
    "Mail" : "E-post",
    "Stream" : "Strøm",
    "Activities" : "Aktiviteter",
    "Error loading activities" : "Feil ved innlasting av aktiviteter",
    "No activities" : "Ingen aktiviteter",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} og {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} og {linkStart}%n mer{linkEnd}","{parameterList} og {linkStart}%n mer{linkEnd}"],
    "in {directory}" : "i {directory}",
    "This stream will show events like additions, changes & shares" : "Denne strømmen vil vise hendelser som f.eks. innlegging, endring og deling",
    "There are no events for this filter" : "Der er ingen hendelser for dette filteret",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "\"remote user\"" : "\"ekstern bruker\"",
    "Activity notification" : "Varsel om aktivitet",
    "All Activities" : "All aktivitet",
    "Activities by you" : "Din aktivitet",
    "Activities by others" : "Andres aktivitet",
    "%s and %s" : "%s og %s",
    "Hello %s," : "Hei %s,",
    "You are receiving this email because the following things happened at %s" : "Du mottar denne e-posten fordi følgende har hendt på %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* og %n til ","* og %n til "],
    "List your own actions in the stream" : "List dine egne handlinger i strømmen",
    "Notify about your own actions via email" : "Varsle om dine egne handliger via e-post",
    "You need to set up your email address before you can receive notification emails." : "Du må sette opp e-postadressen din før du kan motta varslinger på e-post.",
    "Send emails:" : "Send e-poster:",
    "Hourly" : "Hver time",
    "Daily" : "Daglig",
    "Weekly" : "Ukentlig",
    "Activity feed" : "Aktivitetsstrøm",
    "Enable RSS feed" : "Aktiver RSS-strøm",
    "No activity yet" : "Ingen aktivitet ennå",
    "No more events to load" : "Ingen flere hendelser å laste",
    "Files" : "Filer"
},
"nplurals=2; plural=(n != 1);");
